/*
 *  ofSwipeGestureRecognizer.m
 *
 *  Created by Ryan Raffa on 5/13/12.
 *
 *  Based on sample code posted by daanvanhasselt on the openFrameworks forum
 *
 */

#import "ofxiOSSwipeRecognizer.h"  


ofxiOSSwipeRecognizer::ofxiOSSwipeRecognizer(){ }

void ofxiOSSwipeRecognizer::setup(ofxiOSSwipeDirection _direction){
    EAGLView *view = ofxiPhoneGetGLView();
    swipeRecognizer = [[ofSwipeGestureRecognizer alloc] initWithView:view];
    [swipeRecognizer setNotifier:this];
    [swipeRecognizer setDirection:_direction];
}

void ofxiOSSwipeRecognizer::gestureRecognized(ofxiOSSwipeEventArgs args){
    ofNotifyEvent(swipeRecognized, args);
}

// --------------------------------------------------------------------------------
@implementation ofSwipeGestureRecognizer  

-(id)initWithView:(UIView*)view{
    if((self = [super init])){  
        swipeGestureRecognizer = [[UISwipeGestureRecognizer alloc] initWithTarget:self action:@selector(handleSwipe:)];
        [view addGestureRecognizer:swipeGestureRecognizer];
        swipeGestureRecognizer.cancelsTouchesInView = NO;
        [swipeGestureRecognizer release];
        [self setDirection:OFXIOS_SWIPE_DIRECTION_LEFT]; // this is the default for UISwipeRecognizer
    }  
    return self;  
}

- (void) setNotifier:(ofxiOSSwipeRecognizer *)_notifier{
    notifier = _notifier;
}

- (void) setDirection:(ofxiOSSwipeDirection) _direction{
    direction = _direction;
    switch (direction) {
        case OFXIOS_SWIPE_DIRECTION_LEFT:
            [swipeGestureRecognizer setDirection:UISwipeGestureRecognizerDirectionLeft];
            break;
        case OFXIOS_SWIPE_DIRECTION_RIGHT:
            [swipeGestureRecognizer setDirection:UISwipeGestureRecognizerDirectionRight];
            break;
        case OFXIOS_SWIPE_DIRECTION_UP:
            [swipeGestureRecognizer setDirection:UISwipeGestureRecognizerDirectionUp];
            break;
        case OFXIOS_SWIPE_DIRECTION_DOWN:
            [swipeGestureRecognizer setDirection:UISwipeGestureRecognizerDirectionDown];
            break;
    }
}


-(void)handleSwipe:(UISwipeGestureRecognizer *) gr{  
    if([gr state] == UIGestureRecognizerStateRecognized){
        ofxiOSSwipeEventArgs args;
        args.direction = direction;
        args.numTouches = 1;         // fixed for now
        notifier->gestureRecognized(args);
    }
}  

-(void)dealloc{  
    [swipeGestureRecognizer release];  
    [super dealloc];  
}  

@end